import pynumato.pynumato as pynumato
import time

delay=1
nb_run=5
port="COM27"
print("Run test ...")

for i in range(0,nb_run):
    print("Run ",i)
    numatoRelay= pynumato.Numato(numberRelays=2, port=port, baudrate=921600, timeout=delay)
    numatoRelay.get_version()

    numatoRelay.open_single_relay(0)
    time.sleep(delay)
    assert numatoRelay.get_single_relay(0)==1

    numatoRelay.close_single_relay(0)
    time.sleep(delay)
    assert numatoRelay.get_single_relay(0)==0

    numatoRelay.read_single_relay(1)
    numatoRelay.read_all_relays()

    numatoRelay.open_all_relays()
    time.sleep(delay)
    assert numatoRelay.get_single_relay(0)==1
    assert numatoRelay.get_single_relay(1)==1

    numatoRelay.close_all_relays()
    time.sleep(delay)
    assert numatoRelay.get_single_relay(0)==0
    assert numatoRelay.get_single_relay(1)==0

    numatoRelay.update_all_relays("oo")
    time.sleep(delay)
    assert numatoRelay.get_single_relay(0)==1
    assert numatoRelay.get_single_relay(1)==1

    numatoRelay.update_all_relays("cc")
    time.sleep(delay)
    assert numatoRelay.get_single_relay(0)==0
    assert numatoRelay.get_single_relay(1)==0

    numatoRelay.update_all_relays("oc")
    time.sleep(delay)
    assert numatoRelay.get_single_relay(0)==1
    assert numatoRelay.get_single_relay(1)==0

    numatoRelay.update_all_relays("co")
    time.sleep(delay)
    assert numatoRelay.get_single_relay(0)==0
    assert numatoRelay.get_single_relay(1)==1

    numatoRelay.update_all_relays("xx")
    time.sleep(delay)
    assert numatoRelay.get_single_relay(0)==0
    assert numatoRelay.get_single_relay(1)==1

# numatoRelay.reset()
# time.sleep(delay)
# print("get=",numatoRelay.get_single_relay(0))
# assert numatoRelay.get_single_relay(0)== 0
# print("get=",numatoRelay.get_single_relay(1))
# assert numatoRelay.get_single_relay(1)== 0

print("Run test Success")



import sys
import serial
import os
import argparse

class Numato(object):
    def __init__(self, *, numberRelays=1, port="COM27", baudrate=921600, timeout=1):
        self.version = 0
        self.numberRelays= numberRelays
        self.stateRelays=[0]*numberRelays
        self.port=port
        self.baudrate=baudrate
        self.timeout=timeout

        self.read_all_relays()

    def send_cmd(self, cmd, *, noResponse=True, sizeResponse=0):
        #Open port for communication
        serPort = serial.Serial(port=self.port, baudrate=self.baudrate, timeout=self.timeout)

        # Send command
        serPort.write(cmd.encode())

        # Get response command
        if not(noResponse):
            ret = serPort.read(sizeResponse)
            response = ret.decode('UTF-8')

        #Close the port
        serPort.close()

        if not(noResponse):
            return response

    def get_version(self):
        cmd="ver\n\r"
        response = self.send_cmd(cmd=cmd, noResponse= False, sizeResponse=25)
        #print("response=", response)
        version=int(response[len(cmd):-1])
        print("Version is", version)
        return version

    def reset(self):
        cmd="reset\n\r"
        self.send_cmd(cmd=cmd)
        print("Reset all relays")

    #----- functions for single relay -----#
    def open_single_relay(self, indexRelay):
        cmd="relay on "+ str(indexRelay) + "\n\r"
        self.send_cmd(cmd=cmd)
        self.stateRelays[indexRelay] = 1

    def close_single_relay(self, indexRelay):
        cmd="relay off "+ str(indexRelay) + "\n\r"
        self.send_cmd(cmd=cmd)
        self.stateRelays[indexRelay] = 0

    def read_single_relay(self, indexRelay):
        cmd="relay read "+str(indexRelay)+"\n\r"
        ret = self.send_cmd(cmd=cmd, noResponse= False, sizeResponse=25)
        if(ret.find("on") > 0):
            self.stateRelays[indexRelay] = 1
        elif(ret.find("off") > 0):
            self.stateRelays[indexRelay] = 0

    def get_single_relay(self,indexRelay):
        if self.stateRelays[indexRelay]:
            print("Relay " + str(indexRelay) +" is ON")
        else:
            print("Relay " + str(indexRelay) +" is OFF")
        return self.stateRelays[indexRelay]

    #----- functions for all relay -----#
    def read_all_relays(self):
        cmd="relay readall\n\r"
        response = self.send_cmd(cmd=cmd, noResponse= False, sizeResponse=25)
        #print("response=",response)
        states=int(response[len(cmd):-1])
        for i in range(0,self.numberRelays):
            if ((states >> i) & 0x01) == 0x01 :
                self.stateRelays[i]=1
            else:
                self.stateRelays[i]=0

    def open_all_relays(self):
        cmd="relay writeall ff\n\r"
        self.send_cmd(cmd=cmd)
        for i in range(0,self.numberRelays):
            self.stateRelays[i]=1

    def close_all_relays(self):
        cmd="relay writeall 0\n\r"
        self.send_cmd(cmd=cmd)
        for i in range(0,self.numberRelays):
            self.stateRelays[i]=0

    def update_all_relays(self,cmdRelay= "xxxxxxxx"):
        assert(len(cmdRelay) <= self.numberRelays)
        for idxRelay in range(len(cmdRelay)):
            if cmdRelay[idxRelay] == 'o':
                self.open_single_relay(idxRelay)
            elif cmdRelay[idxRelay] == 'c':
                self.close_single_relay(idxRelay)

def main(args=None):
    scriptname = os.path.basename(__file__)
    parser = argparse.ArgumentParser(scriptname)
    parser.add_argument('--relays', default=1, type=int)
    parser.add_argument('--port', default="/dev/ttyUSB1", type=str)
    parser.add_argument('--timeout', default=1, type=int)
    parser.add_argument('--baudrate', default=921600, type=int)
    parser.add_argument('--cmd', default="x", type=str)

    options = parser.parse_args()

    numatoRelay= Numato(numberRelays=options.relays, port=options.port, baudrate=options.baudrate, timeout=options.timeout)
    numatoRelay.update_all_relays(cmdRelay=options.cmd)

    return 0

if __name__=="__main__":
    ret=main()
    os._exit(ret)



"""Library to communicate with relays

"""

__version__ = '0.0.1'
__title__ = 'pynumato'
__description__ = 'Library to communicate with relay module - numato series'
#__uri__ = 'https://github.com/Tiempogithub/...'
#__doc__ = __description__ + ' <' + __uri__ + '>'
__author__ = 'Tiempo'
# For all support requests, please open a new issue on GitHub
__email__ = 'henitsoa.rakotomalala@tiempo-secure.com'
__copyright__ = 'Tiempo-Secure'



import setuptools
from codecs import open as codec_open
from os import close, unlink
from os.path import abspath, dirname, join as joinpath
from re import split as resplit, search as research

META_PATH = joinpath('pynumato', '__init__.py')

HERE = abspath(dirname(__file__))


def read(*parts):
    """
    Build an absolute path from *parts* and and return the contents of the
    resulting file.  Assume UTF-8 encoding.
    """
    with codec_open(joinpath(HERE, *parts), 'rb', 'utf-8') as dfp:
        return dfp.read()


def read_desc(*parts):
    """Read and filter long description
    """
    text = read(*parts)
    text = resplit(r'\.\.\sEOT', text)[0]
    return text


META_FILE = read(META_PATH)


def find_meta(meta):
    """
    Extract __*meta*__ from META_FILE.
    """
    meta_match = research(
        r"(?m)^__{meta}__ = ['\"]([^'\"]*)['\"]".format(meta=meta),
        META_FILE
    )
    if meta_match:
        return meta_match.group(1)
    raise RuntimeError("Unable to find __{meta}__ string.".format(meta=meta))

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()
    print(long_description)

setuptools.setup(
    name="pynumato",
    version=find_meta('version'),
    author="Tiempo",
    author_email="henitsoa.rakotomalala@tiempo-secure.com",
    description="Library to communicate with relays",
    long_description = long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/henitsoa-tiempo/pynumato.git",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
    include_package_data=True,
    install_requires=[
        ],
)

# setuptools.setup(
#     name=find_meta('title'),
#     version=find_meta('version'),
#     author=find_meta('author'),
#     author_email=find_meta('email'),
#     description=find_meta('description'),
#     long_description = long_description,
#     long_description_content_type="text/markdown",
#     url=find_meta('uri'),
#     packages=setuptools.find_packages(),
#     package_dir={'': '.'},
#     classifiers=[
#         "Programming Language :: Python :: 3",
#         "License :: OSI Approved :: Apache Software License",
#         "Operating System :: OS Independent",
#         "Development Status :: 5 - Production/Stable"
#     ],
#     python_requires='>=3.6',
# )
